@@ -16,14 +16,25 @@
 
 from keystonemiddleware import auth_token
 from oslo_config import cfg
+from oslo_policy import opts
 from oslo_policy import policy
 
 from mistral import exceptions as exc
 from mistral import policies
 
+
+CONF = cfg.CONF
+
 _ENFORCER = None
 
 
+# TODO(gmann): Remove setting the default value of config policy_file
+# once oslo_policy change the default value to 'policy.yaml'.
+# https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
+DEFAULT_POLICY_FILE = 'policy.yaml'
+opts.set_defaults(CONF, DEFAULT_POLICY_FILE)
+
+
 def setup(app):
     if cfg.CONF.pecan.auth_enable and cfg.CONF.auth_type == 'keystone':
         conf = dict(cfg.CONF.keystone_authtoken)
@@ -68,7 +79,7 @@ def enforce(action, context, target=None, do_raise=True,
     target_obj.update(target or {})
 
     policy_context = context.to_policy_values()
-    # Because policy.json or policy.yaml example in Mistral repo still uses
+    # Because policy.yaml or policy.yaml example in Mistral repo still uses
     # the rule 'is_admin: True', we insert 'is_admin' key to the default
     # policy values.
     policy_context['is_admin'] = context.is_admin
@@ -84,6 +95,26 @@ def enforce(action, context, target=None, do_raise=True,
     )
 
 
+def get_enforcer():
+    """Entrypoint that must return the raw oslo.policy enforcer obj.
+
+    This is utilized by the command-line policy tools.
+
+    :returns: :class:`oslo_policy.policy.Enforcer`
+    """
+    # Here we pass an empty list of arguments because there aren't any
+    # arguments that oslo.config or oslo.policy shouldn't already understand
+    # from the CONF object. This makes things easier here because we don't have
+    # to parse arguments passed in from the command line and remove unexpected
+    # arguments before building a Config object.
+    CONF([], project='mistral')
+    enforcer = policy.Enforcer(CONF)
+    enforcer.register_defaults(policies.list_rules())
+    enforcer.load_rules()
+
+    return enforcer
+
+
 def _ensure_enforcer_initialization():
     global _ENFORCER
     if not _ENFORCER:
